/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { ElementRef, QueryList, Renderer2 } from '@angular/core';
import { BuiltInControlValueAccessor, ControlValueAccessor } from './control_value_accessor';
import * as i0 from "@angular/core";
export declare const CHECKBOX_VALUE_ACCESSOR: any;
export declare class CheckBoxGroupValueAccessor extends BuiltInControlValueAccessor implements ControlValueAccessor {
    children: QueryList<CheckboxControl>;
    valueChange(list: string[]): void;
    writeValue(list: string[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckBoxGroupValueAccessor, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CheckBoxGroupValueAccessor, "checkbox-group[formControlName],checkbox-group[formControl],checkbox-group[ngModel]", never, {}, {}, ["children"], never, false, never>;
}
/**
 * @description
 * A `ControlValueAccessor` for writing a value and listening to changes on a checkbox input
 * element.
 *
 * @usageNotes
 *
 * ### Using a checkbox with a reactive form.
 *
 * The following example shows how to use a checkbox with a reactive form.
 *
 * ```ts
 * const rememberLoginControl = new FormControl();
 * ```
 *
 * ```
 * <input type="checkbox" [formControl]="rememberLoginControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */
export declare class CheckboxControl {
    private elementRef;
    private renderer;
    /**
     * @description
     * Tracks the value of the radio input element
     */
    readonly value: string | undefined;
    checked: boolean | undefined;
    constructor(elementRef: ElementRef, renderer: Renderer2);
    updateChecked(value: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckboxControl, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CheckboxControl, "checkbox", never, { "value": { "alias": "value"; "required": false; }; }, {}, never, never, false, never>;
}



declare const CheckBoxGroupValueAccessor_Listeners:["bindchange"];
declare const CheckBoxGroupValueAccessor_Properties:[];
declare const CheckboxControl_Listeners:[];
declare const CheckboxControl_Properties:["value","checked"];