import { BuiltInControlValueAccessor, ControlValueAccessor } from './control_value_accessor';
import * as i0 from "@angular/core";
export declare const NUMBER_VALUE_ACCESSOR: any;
/**
 * @description
 * The `ControlValueAccessor` for writing a number value and listening to number input changes.
 * The value accessor is used by the `FormControlDirective`, `FormControlName`, and `NgModel`
 * directives.
 *
 * @usageNotes
 *
 * ### Using a number input with a reactive form.
 *
 * The following example shows how to use a number input with a reactive form.
 *
 * ```ts
 * const totalCountControl = new FormControl();
 * ```
 *
 * ```
 * <input type="number" [formControl]="totalCountControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */
export declare class SliderValueAccessor extends BuiltInControlValueAccessor implements ControlValueAccessor {
    value: number | undefined;
    disabled: boolean | undefined;
    /**
     * Sets the "value" property on the input element.
     * @nodoc
     */
    writeValue(value: number): void;
    valueChange(value: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SliderValueAccessor, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SliderValueAccessor, "slider[formControlName],slider[formControl],slider[ngModel]", never, {}, {}, never, never, false, never>;
}



declare const SliderValueAccessor_Listeners:["bindchange"];
declare const SliderValueAccessor_Properties:["value","disabled"];