import { BuiltInControlValueAccessor, ControlValueAccessor } from './control_value_accessor';
import * as i0 from "@angular/core";
export declare const SWITCH_VALUE_ACCESSOR: any;
/**
 * @description
 * The `ControlValueAccessor` for writing a number value and listening to number input changes.
 * The value accessor is used by the `FormControlDirective`, `FormControlName`, and `NgModel`
 * directives.
 *
 * @usageNotes
 *
 * ### Using a number input with a reactive form.
 *
 * The following example shows how to use a number input with a reactive form.
 *
 * ```ts
 * const totalCountControl = new FormControl();
 * ```
 *
 * ```
 * <input type="number" [formControl]="totalCountControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */
export declare class SwitchValueAccessor extends BuiltInControlValueAccessor implements ControlValueAccessor {
    value: boolean | undefined;
    disabled: boolean | undefined;
    /**
     * Sets the "value" property on the input element.
     * @nodoc
     */
    writeValue(value: boolean): void;
    valueChange(value: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SwitchValueAccessor, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SwitchValueAccessor, "switch[formControlName],switch[formControl],switch[ngModel]", never, {}, {}, never, never, false, never>;
}



declare const SwitchValueAccessor_Listeners:["bindchange"];
declare const SwitchValueAccessor_Properties:["checked","disabled"];